@@ -10,18 +10,16 @@ class ExperimentAnalysis(ABC):
     Abstract class to run the analysis of a given experiment
 
     In order to create your own ExperimentAnalysis,
-    you should create a derived class that implements the get_pvalue method.
+    you should create a derived class that implements the analysis_pvalue method.
     """
 
     def __init__(
         self,
         cluster_cols: List[str],
-        *args,
         target_col: str = "target",
         treatment_col: str = "treatment",
         treatment: str = "B",
         covariates: Optional[List[str]] = None,
-        **kwargs,
     ):
         """
         Creates an object to run the analysis of a given experiment, after the data is collected.
@@ -29,20 +27,16 @@ class ExperimentAnalysis(ABC):
 
         Arguments:
             cluster_cols: list of columns to use as clusters
-            args: Specific positional arguments for the derived analysis class
             target_col: name of the column containing the variable to measure
             treatment_col: name of the column containing the treatment variable
             treatment: name of the treatment to use as the treated group
             covariates: list of columns to use as covariates
-            kwargs: Specific keyword arguments for the derived analysis class
         """
         self.target_col = target_col
         self.treatment = treatment
         self.treatment_col = treatment_col
         self.cluster_cols = cluster_cols
         self.covariates = covariates or []
-        self.args = args
-        self.kwargs = kwargs
 
     def _get_cluster_column(self, df: pd.DataFrame) -> pd.Series:
         """Paste all strings of cluster_cols in one single column"""
@@ -56,13 +50,23 @@ class ExperimentAnalysis(ABC):
         return df
 
     @abstractmethod
-    def get_pvalue(
+    def analysis_pvalue(
         self,
         df: pd.DataFrame,
     ) -> float:
-        """Returns the p-value of the analysis"""
+        """Returns the p-value of the analysis. Expects treatment to be 0-1 variable"""
         pass
 
+    def get_pvalue(self, df: pd.DataFrame) -> float:
+        """Returns the p-value of the analysis
+
+        Arguments:
+            df: dataframe containing the data to analyze
+        """
+        df = df.copy()
+        df = self._create_binary_treatment(df)
+        return self.analysis_pvalue(df)
+
     @classmethod
     def from_config(cls, config):
         """Creates an ExperimentAnalysis object from a PowerConfig object"""
@@ -112,24 +116,17 @@ class GeeExperimentAnalysis(ExperimentAnalysis):
             treatment=treatment,
             covariates=covariates,
         )
+        self.regressors = [self.treatment_col] + self.covariates
+        self.formula = f"{self.target_col} ~ {' + '.join(self.regressors)}"
         self.fam = sm.families.Gaussian()
         self.va = sm.cov_struct.Exchangeable()
 
-    def set_formula(self):
-        """Returns the formula used in the analysis"""
-        self.regressors = [self.treatment_col] + self.covariates
-        self.formula = f"{self.target_col} ~ {' + '.join(self.regressors)}"
-
-    def get_pvalue(self, df: pd.DataFrame) -> float:
+    def analysis_pvalue(self, df: pd.DataFrame) -> float:
         """Returns the p-value of the analysis
 
         Arguments:
             df: dataframe containing the data to analyze
         """
-        df = df.copy()
-        df = self._create_binary_treatment(df)
-        self.set_formula()
-
         results_gee = sm.GEE.from_formula(
             self.formula,
             data=df,
