@@ -1,7 +1,10 @@
+import logging
 from typing import List, Optional, Tuple
 
 import pandas as pd
+from pandas.api.types import is_numeric_dtype
 from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
+from tqdm import tqdm
 
 from cluster_experiments.cupac import EmptyRegressor
 from cluster_experiments.experiment_analysis import ExperimentAnalysis
@@ -112,6 +115,18 @@ class PowerAnalysis:
         self.treatment_col = treatment_col
         self.alpha = alpha
         self.features_cupac_model: List[str] = features_cupac_model or []
+        self.is_cupac = not isinstance(self.cupac_model, EmptyRegressor)
+
+        cupac_not_in_covariates = (
+            self.cupac_outcome_name not in self.analysis.covariates
+        )
+
+        if self.is_cupac and cupac_not_in_covariates:
+            raise ValueError(
+                f"covariates in analysis must contain {self.cupac_outcome_name} if cupac_model is not None. "
+                f"If you want to use cupac_model, you must add the cupac outcome to the covariates of the analysis "
+                f"You may want to do covariates=['{self.cupac_outcome_name}'] in your analysis method or your config"
+            )
 
     def _prep_data_cupac(
         self, df: pd.DataFrame, pre_experiment_df: pd.DataFrame
@@ -161,22 +176,35 @@ class PowerAnalysis:
                 "cupac_model should be an instance of RegressorMixin or ClassifierMixin"
             )
 
-        # Add cupac outcome name to df and self.analysis
-
+        # Add cupac outcome name to df
         df[self.cupac_outcome_name] = estimated_target
-        if self.cupac_outcome_name not in self.analysis.covariates:
-            print("adding covariates to analyser")
-            self.analysis.covariates.append(self.cupac_outcome_name)
         return df
 
     def log_nulls(self, df: pd.DataFrame) -> None:
         """Warns about dropping nulls in treatment column"""
         n_nulls = len(df.query(f"{self.treatment_col}.isnull()"))
         if n_nulls > 0:
-            print(f"There are {n_nulls} null values in treatment, dropping them")
+            logging.warning(
+                f"There are {n_nulls} null values in treatment, dropping them"
+            )
+
+    def _data_checks(self, df: pd.DataFrame) -> None:
+        """Checks that the data is correct"""
+        if df[self.target_col].isnull().any():
+            raise ValueError(
+                f"There are null values in outcome column {self.treatment_col}"
+            )
+
+        if not is_numeric_dtype(df[self.target_col]):
+            raise ValueError(
+                f"Outcome column {self.target_col} should be numeric and not {df[self.target_col].dtype}"
+            )
 
     def power_analysis(
-        self, df: pd.DataFrame, pre_experiment_df: Optional[pd.DataFrame] = None
+        self,
+        df: pd.DataFrame,
+        pre_experiment_df: Optional[pd.DataFrame] = None,
+        verbose: bool = False,
     ) -> float:
         """
         Run power analysis by simulation
@@ -186,13 +214,14 @@ class PowerAnalysis:
         """
         df = df.copy()
 
-        if pre_experiment_df is not None and not isinstance(
-            self.cupac_model, EmptyRegressor
-        ):
+        self._data_checks(df=df)
+
+        if pre_experiment_df is not None and self.is_cupac:
             df = self.add_covariates(df, pre_experiment_df)
 
         n_detected_mde = 0
-        for _ in range(self.n_simulations):
+
+        for _ in tqdm(range(self.n_simulations), disable=not verbose):
             treatment_df = self.splitter.assign_treatment_df(df)
             self.log_nulls(treatment_df)
             treatment_df = treatment_df.query(f"{self.treatment_col}.notnull()")
